/* OGroup.h	by Paul Kunz	March 1991
 * Group of Plot graphics that overlay each other.
 *
 * Copyright (C)  1992  The Board of Trustees of
 * The Leland Stanford Junior University.  All Rights Reserved.
 */
 
#define OVERLAY_H_ID "$Id: Overlay.h,v 2.7 1993/02/14 21:54:56 pfkeb Exp $"

#import "groupPlot.h"
#import "hippo.h"

@interface Overlay : Group
{
    id		firstPlot;	/* Controling Plot of the Group, */
    NXRect	initialRect;	/* NXRect covering initial Plot's bounds*/
}

- initList:list with:plot;
 /*
  * The designated initializer for the class. The plot is the one that
  * will control the axes and titles.  Overlays other Plots in 
  * the Group and turns off their axes labels and titles.
  */

- (NXRect *) getInitialBounds:(NXRect *)initBounds;
 /*
  * Returns, by reference, the inital bounds which covered all the Plots in
  * the group.
  */
- checkBounds;
 /*
  * Checks if bounding box is within the DrawDocuments frame.   If
  * not, move the bounding box so that it is contained in the frame.
  */
  
- transferSubGraphicsTo:list at:(int)position;
 /*
  * Turns on the axes labels and titles of all Plots in the
  * Group, then uses its super class method of the same name.
  */   

- firstPlot;
 /*
  * Returns the controlling plot of the Group.
  */
  
- NameAxisX:(const char *) value;
 /*
  * Sets the label of the x-axis of the controling Plot in the Group.
  */

- NameAxisY:(const char *) value;
 /*
  * Sets the label of the y-axis of the controling Plot in the Group.
  */

- setAutoScale:(binding_t *)axis to:(const int *) value;
 /*
  * Responds to the autoscale being turned on by scaling the
  * x-axis of all Plots in the Group so all data is visible
  */
  
- setRange:(binding_t* ) axis to:(const NXPoint *)p;
 /*
  * Sets range on axis axis for all Plots in the overlay group.
  */
  
- setTitle:(const char *) value;
 /*
  * Sets the title of the controling Plot in the Group.
  */
  
- setTitlesFlag:(const int *) value;
 /*
  * Sets the titles flag of the controling Plot in the Group.
  */

- write:(NXTypedStream *) ts;
 /*
  * An archiving method.
  */

- read:(NXTypedStream *)ts;
 /*
  * An archiving method.  
  */

@end
